# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/community.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/community/community.proto',
  package='eolymp.community',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/community;community',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/community/community.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\"N\n\x0eJoinSpaceInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"$\n\x0fJoinSpaceOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"E\n\x13RegisterMemberInput\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"\x16\n\x14RegisterMemberOutput\"\x11\n\x0fLeaveSpaceInput\"\x12\n\x10LeaveSpaceOutput\":\n\x0e\x41\x64\x64MemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"$\n\x0f\x41\x64\x64MemberOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"P\n\x11UpdateMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12(\n\x06member\x18\x02 \x01(\x0b\x32\x18.eolymp.community.Member\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\x17\n\x15IntrospectMemberInput\"B\n\x16IntrospectMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xba\x02\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x1a\xcb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x08\x64isabled\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"Z\n\x11\x41\x64\x64\x41ttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x14\n\x12\x41\x64\x64\x41ttributeOutput\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute2\xb9\x13\n\tCommunity\x12\x98\x01\n\tJoinSpace\x12 .eolymp.community.JoinSpaceInput\x1a!.eolymp.community.JoinSpaceOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x14\x1a\x0f/community/selfb\x01*\x12\x9b\x01\n\nLeaveSpace\x12!.eolymp.community.LeaveSpaceInput\x1a\".eolymp.community.LeaveSpaceOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x14*\x0f/community/selfb\x01*\x12\xa8\x01\n\x0eRegisterMember\x12%.eolymp.community.RegisterMemberInput\x1a&.eolymp.community.RegisterMemberOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x14\"\x0f/community/selfb\x01*\x12\xb2\x01\n\x10IntrospectMember\x12\'.eolymp.community.IntrospectMemberInput\x1a(.eolymp.community.IntrospectMemberOutput\"K\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x19\x12\x0f/community/selfb\x06member\x12\x9c\x01\n\tAddMember\x12 .eolymp.community.AddMemberInput\x1a!.eolymp.community.AddMemberOutput\"J\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\"\x12/community/membersb\x01*\x12\xb1\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#\x1a\x1e/community/members/{member_id}b\x01*\x12\xb1\x01\n\x0cRemoveMember\x12#.eolymp.community.RemoveMemberInput\x1a$.eolymp.community.RemoveMemberOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#*\x1e/community/members/{member_id}b\x01*\x12\xbb\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"Z\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02(\x12\x1e/community/members/{member_id}b\x06member\x12\xa1\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"I\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\x12\x12/community/membersb\x01*\x12\xa8\x01\n\x0c\x41\x64\x64\x41ttribute\x12#.eolymp.community.AddAttributeInput\x1a$.eolymp.community.AddAttributeOutput\"M\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a\"\x15/community/attributesb\x01*\x12\xc1\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"]\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x1a%/community/attributes/{attribute_key}b\x01*\x12\xc1\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"]\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02**%/community/attributes/{attribute_key}b\x01*\x12\xc6\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"\\\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x12%/community/attributes/{attribute_key}b\x01*\x12\xad\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"L\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a\x12\x15/community/attributesb\x01*B;Z9github.com/eolymp/contracts/go/eolymp/community;communityb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_community_dot_attribute__pb2.DESCRIPTOR,eolymp_dot_community_dot_member__pb2.DESCRIPTOR,])




_JOINSPACEINPUT = _descriptor.Descriptor(
  name='JoinSpaceInput',
  full_name='eolymp.community.JoinSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.community.JoinSpaceInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='eolymp.community.JoinSpaceInput.values', index=1,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=331,
)


_JOINSPACEOUTPUT = _descriptor.Descriptor(
  name='JoinSpaceOutput',
  full_name='eolymp.community.JoinSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.JoinSpaceOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=369,
)


_REGISTERMEMBERINPUT = _descriptor.Descriptor(
  name='RegisterMemberInput',
  full_name='eolymp.community.RegisterMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='eolymp.community.RegisterMemberInput.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=440,
)


_REGISTERMEMBEROUTPUT = _descriptor.Descriptor(
  name='RegisterMemberOutput',
  full_name='eolymp.community.RegisterMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=464,
)


_LEAVESPACEINPUT = _descriptor.Descriptor(
  name='LeaveSpaceInput',
  full_name='eolymp.community.LeaveSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=483,
)


_LEAVESPACEOUTPUT = _descriptor.Descriptor(
  name='LeaveSpaceOutput',
  full_name='eolymp.community.LeaveSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=503,
)


_ADDMEMBERINPUT = _descriptor.Descriptor(
  name='AddMemberInput',
  full_name='eolymp.community.AddMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.AddMemberInput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=563,
)


_ADDMEMBEROUTPUT = _descriptor.Descriptor(
  name='AddMemberOutput',
  full_name='eolymp.community.AddMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.AddMemberOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=601,
)


_UPDATEMEMBERINPUT = _descriptor.Descriptor(
  name='UpdateMemberInput',
  full_name='eolymp.community.UpdateMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.UpdateMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.UpdateMemberInput.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=683,
)


_UPDATEMEMBEROUTPUT = _descriptor.Descriptor(
  name='UpdateMemberOutput',
  full_name='eolymp.community.UpdateMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=705,
)


_REMOVEMEMBERINPUT = _descriptor.Descriptor(
  name='RemoveMemberInput',
  full_name='eolymp.community.RemoveMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.RemoveMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=745,
)


_REMOVEMEMBEROUTPUT = _descriptor.Descriptor(
  name='RemoveMemberOutput',
  full_name='eolymp.community.RemoveMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=767,
)


_DESCRIBEMEMBERINPUT = _descriptor.Descriptor(
  name='DescribeMemberInput',
  full_name='eolymp.community.DescribeMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.community.DescribeMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=809,
)


_DESCRIBEMEMBEROUTPUT = _descriptor.Descriptor(
  name='DescribeMemberOutput',
  full_name='eolymp.community.DescribeMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.DescribeMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=875,
)


_INTROSPECTMEMBERINPUT = _descriptor.Descriptor(
  name='IntrospectMemberInput',
  full_name='eolymp.community.IntrospectMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=900,
)


_INTROSPECTMEMBEROUTPUT = _descriptor.Descriptor(
  name='IntrospectMemberOutput',
  full_name='eolymp.community.IntrospectMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.community.IntrospectMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=968,
)


_LISTMEMBERSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.community.ListMembersInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.community.ListMembersInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.community.ListMembersInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='eolymp.community.ListMembersInput.Filter.disabled', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.community.ListMembersInput.Filter.name', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1285,
)

_LISTMEMBERSINPUT = _descriptor.Descriptor(
  name='ListMembersInput',
  full_name='eolymp.community.ListMembersInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.community.ListMembersInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.community.ListMembersInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.community.ListMembersInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEMBERSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1285,
)


_LISTMEMBERSOUTPUT = _descriptor.Descriptor(
  name='ListMembersOutput',
  full_name='eolymp.community.ListMembersOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.community.ListMembersOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.community.ListMembersOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1362,
)


_ADDATTRIBUTEINPUT = _descriptor.Descriptor(
  name='AddAttributeInput',
  full_name='eolymp.community.AddAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.AddAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.AddAttributeInput.attribute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1364,
  serialized_end=1454,
)


_ADDATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='AddAttributeOutput',
  full_name='eolymp.community.AddAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1476,
)


_UPDATEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='UpdateAttributeInput',
  full_name='eolymp.community.UpdateAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.UpdateAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.UpdateAttributeInput.attribute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1571,
)


_UPDATEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='UpdateAttributeOutput',
  full_name='eolymp.community.UpdateAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1596,
)


_REMOVEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='RemoveAttributeInput',
  full_name='eolymp.community.RemoveAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.RemoveAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1643,
)


_REMOVEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='RemoveAttributeOutput',
  full_name='eolymp.community.RemoveAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1668,
)


_DESCRIBEATTRIBUTEINPUT = _descriptor.Descriptor(
  name='DescribeAttributeInput',
  full_name='eolymp.community.DescribeAttributeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_key', full_name='eolymp.community.DescribeAttributeInput.attribute_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1717,
)


_DESCRIBEATTRIBUTEOUTPUT = _descriptor.Descriptor(
  name='DescribeAttributeOutput',
  full_name='eolymp.community.DescribeAttributeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='eolymp.community.DescribeAttributeOutput.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1792,
)


_LISTATTRIBUTESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.community.ListAttributesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.community.ListAttributesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.community.ListAttributesInput.Filter.key', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='eolymp.community.ListAttributesInput.Filter.hidden', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.community.ListAttributesInput.Filter.required', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.community.ListAttributesInput.Filter.type', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=2161,
)

_LISTATTRIBUTESINPUT = _descriptor.Descriptor(
  name='ListAttributesInput',
  full_name='eolymp.community.ListAttributesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.community.ListAttributesInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.community.ListAttributesInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.community.ListAttributesInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTATTRIBUTESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1795,
  serialized_end=2161,
)


_LISTATTRIBUTESOUTPUT = _descriptor.Descriptor(
  name='ListAttributesOutput',
  full_name='eolymp.community.ListAttributesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.community.ListAttributesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.community.ListAttributesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2244,
)

_JOINSPACEINPUT.fields_by_name['values'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER_VALUE
_REGISTERMEMBERINPUT.fields_by_name['values'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER_VALUE
_ADDMEMBERINPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_UPDATEMEMBERINPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_DESCRIBEMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_INTROSPECTMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_LISTMEMBERSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['disabled'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTMEMBERSINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTMEMBERSINPUT_FILTER.containing_type = _LISTMEMBERSINPUT
_LISTMEMBERSINPUT.fields_by_name['filters'].message_type = _LISTMEMBERSINPUT_FILTER
_LISTMEMBERSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_community_dot_member__pb2._MEMBER
_ADDATTRIBUTEINPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_UPDATEATTRIBUTEINPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_DESCRIBEATTRIBUTEOUTPUT.fields_by_name['attribute'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['key'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['hidden'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['required'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTATTRIBUTESINPUT_FILTER.fields_by_name['type'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTATTRIBUTESINPUT_FILTER.containing_type = _LISTATTRIBUTESINPUT
_LISTATTRIBUTESINPUT.fields_by_name['filters'].message_type = _LISTATTRIBUTESINPUT_FILTER
_LISTATTRIBUTESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_community_dot_attribute__pb2._ATTRIBUTE
DESCRIPTOR.message_types_by_name['JoinSpaceInput'] = _JOINSPACEINPUT
DESCRIPTOR.message_types_by_name['JoinSpaceOutput'] = _JOINSPACEOUTPUT
DESCRIPTOR.message_types_by_name['RegisterMemberInput'] = _REGISTERMEMBERINPUT
DESCRIPTOR.message_types_by_name['RegisterMemberOutput'] = _REGISTERMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['LeaveSpaceInput'] = _LEAVESPACEINPUT
DESCRIPTOR.message_types_by_name['LeaveSpaceOutput'] = _LEAVESPACEOUTPUT
DESCRIPTOR.message_types_by_name['AddMemberInput'] = _ADDMEMBERINPUT
DESCRIPTOR.message_types_by_name['AddMemberOutput'] = _ADDMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateMemberInput'] = _UPDATEMEMBERINPUT
DESCRIPTOR.message_types_by_name['UpdateMemberOutput'] = _UPDATEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['RemoveMemberInput'] = _REMOVEMEMBERINPUT
DESCRIPTOR.message_types_by_name['RemoveMemberOutput'] = _REMOVEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeMemberInput'] = _DESCRIBEMEMBERINPUT
DESCRIPTOR.message_types_by_name['DescribeMemberOutput'] = _DESCRIBEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberInput'] = _INTROSPECTMEMBERINPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberOutput'] = _INTROSPECTMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['ListMembersInput'] = _LISTMEMBERSINPUT
DESCRIPTOR.message_types_by_name['ListMembersOutput'] = _LISTMEMBERSOUTPUT
DESCRIPTOR.message_types_by_name['AddAttributeInput'] = _ADDATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['AddAttributeOutput'] = _ADDATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateAttributeInput'] = _UPDATEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['UpdateAttributeOutput'] = _UPDATEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['RemoveAttributeInput'] = _REMOVEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['RemoveAttributeOutput'] = _REMOVEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeAttributeInput'] = _DESCRIBEATTRIBUTEINPUT
DESCRIPTOR.message_types_by_name['DescribeAttributeOutput'] = _DESCRIBEATTRIBUTEOUTPUT
DESCRIPTOR.message_types_by_name['ListAttributesInput'] = _LISTATTRIBUTESINPUT
DESCRIPTOR.message_types_by_name['ListAttributesOutput'] = _LISTATTRIBUTESOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JoinSpaceInput = _reflection.GeneratedProtocolMessageType('JoinSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _JOINSPACEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.JoinSpaceInput)
  })
_sym_db.RegisterMessage(JoinSpaceInput)

JoinSpaceOutput = _reflection.GeneratedProtocolMessageType('JoinSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _JOINSPACEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.JoinSpaceOutput)
  })
_sym_db.RegisterMessage(JoinSpaceOutput)

RegisterMemberInput = _reflection.GeneratedProtocolMessageType('RegisterMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RegisterMemberInput)
  })
_sym_db.RegisterMessage(RegisterMemberInput)

RegisterMemberOutput = _reflection.GeneratedProtocolMessageType('RegisterMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RegisterMemberOutput)
  })
_sym_db.RegisterMessage(RegisterMemberOutput)

LeaveSpaceInput = _reflection.GeneratedProtocolMessageType('LeaveSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _LEAVESPACEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.LeaveSpaceInput)
  })
_sym_db.RegisterMessage(LeaveSpaceInput)

LeaveSpaceOutput = _reflection.GeneratedProtocolMessageType('LeaveSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _LEAVESPACEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.LeaveSpaceOutput)
  })
_sym_db.RegisterMessage(LeaveSpaceOutput)

AddMemberInput = _reflection.GeneratedProtocolMessageType('AddMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddMemberInput)
  })
_sym_db.RegisterMessage(AddMemberInput)

AddMemberOutput = _reflection.GeneratedProtocolMessageType('AddMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddMemberOutput)
  })
_sym_db.RegisterMessage(AddMemberOutput)

UpdateMemberInput = _reflection.GeneratedProtocolMessageType('UpdateMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateMemberInput)
  })
_sym_db.RegisterMessage(UpdateMemberInput)

UpdateMemberOutput = _reflection.GeneratedProtocolMessageType('UpdateMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateMemberOutput)
  })
_sym_db.RegisterMessage(UpdateMemberOutput)

RemoveMemberInput = _reflection.GeneratedProtocolMessageType('RemoveMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveMemberInput)
  })
_sym_db.RegisterMessage(RemoveMemberInput)

RemoveMemberOutput = _reflection.GeneratedProtocolMessageType('RemoveMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveMemberOutput)
  })
_sym_db.RegisterMessage(RemoveMemberOutput)

DescribeMemberInput = _reflection.GeneratedProtocolMessageType('DescribeMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeMemberInput)
  })
_sym_db.RegisterMessage(DescribeMemberInput)

DescribeMemberOutput = _reflection.GeneratedProtocolMessageType('DescribeMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeMemberOutput)
  })
_sym_db.RegisterMessage(DescribeMemberOutput)

IntrospectMemberInput = _reflection.GeneratedProtocolMessageType('IntrospectMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBERINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.IntrospectMemberInput)
  })
_sym_db.RegisterMessage(IntrospectMemberInput)

IntrospectMemberOutput = _reflection.GeneratedProtocolMessageType('IntrospectMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBEROUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.IntrospectMemberOutput)
  })
_sym_db.RegisterMessage(IntrospectMemberOutput)

ListMembersInput = _reflection.GeneratedProtocolMessageType('ListMembersInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEMBERSINPUT_FILTER,
    '__module__' : 'eolymp.community.community_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTMEMBERSINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersInput)
  })
_sym_db.RegisterMessage(ListMembersInput)
_sym_db.RegisterMessage(ListMembersInput.Filter)

ListMembersOutput = _reflection.GeneratedProtocolMessageType('ListMembersOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListMembersOutput)
  })
_sym_db.RegisterMessage(ListMembersOutput)

AddAttributeInput = _reflection.GeneratedProtocolMessageType('AddAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddAttributeInput)
  })
_sym_db.RegisterMessage(AddAttributeInput)

AddAttributeOutput = _reflection.GeneratedProtocolMessageType('AddAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.AddAttributeOutput)
  })
_sym_db.RegisterMessage(AddAttributeOutput)

UpdateAttributeInput = _reflection.GeneratedProtocolMessageType('UpdateAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateAttributeInput)
  })
_sym_db.RegisterMessage(UpdateAttributeInput)

UpdateAttributeOutput = _reflection.GeneratedProtocolMessageType('UpdateAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.UpdateAttributeOutput)
  })
_sym_db.RegisterMessage(UpdateAttributeOutput)

RemoveAttributeInput = _reflection.GeneratedProtocolMessageType('RemoveAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveAttributeInput)
  })
_sym_db.RegisterMessage(RemoveAttributeInput)

RemoveAttributeOutput = _reflection.GeneratedProtocolMessageType('RemoveAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.RemoveAttributeOutput)
  })
_sym_db.RegisterMessage(RemoveAttributeOutput)

DescribeAttributeInput = _reflection.GeneratedProtocolMessageType('DescribeAttributeInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEATTRIBUTEINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeAttributeInput)
  })
_sym_db.RegisterMessage(DescribeAttributeInput)

DescribeAttributeOutput = _reflection.GeneratedProtocolMessageType('DescribeAttributeOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEATTRIBUTEOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.DescribeAttributeOutput)
  })
_sym_db.RegisterMessage(DescribeAttributeOutput)

ListAttributesInput = _reflection.GeneratedProtocolMessageType('ListAttributesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTATTRIBUTESINPUT_FILTER,
    '__module__' : 'eolymp.community.community_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTATTRIBUTESINPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesInput)
  })
_sym_db.RegisterMessage(ListAttributesInput)
_sym_db.RegisterMessage(ListAttributesInput.Filter)

ListAttributesOutput = _reflection.GeneratedProtocolMessageType('ListAttributesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTRIBUTESOUTPUT,
  '__module__' : 'eolymp.community.community_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.ListAttributesOutput)
  })
_sym_db.RegisterMessage(ListAttributesOutput)


DESCRIPTOR._options = None

_COMMUNITY = _descriptor.ServiceDescriptor(
  name='Community',
  full_name='eolymp.community.Community',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2247,
  serialized_end=4736,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinSpace',
    full_name='eolymp.community.Community.JoinSpace',
    index=0,
    containing_service=None,
    input_type=_JOINSPACEINPUT,
    output_type=_JOINSPACEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\024\032\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveSpace',
    full_name='eolymp.community.Community.LeaveSpace',
    index=1,
    containing_service=None,
    input_type=_LEAVESPACEINPUT,
    output_type=_LEAVESPACEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\024*\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterMember',
    full_name='eolymp.community.Community.RegisterMember',
    index=2,
    containing_service=None,
    input_type=_REGISTERMEMBERINPUT,
    output_type=_REGISTERMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\024\"\017/community/selfb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectMember',
    full_name='eolymp.community.Community.IntrospectMember',
    index=3,
    containing_service=None,
    input_type=_INTROSPECTMEMBERINPUT,
    output_type=_INTROSPECTMEMBEROUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\031\022\017/community/selfb\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddMember',
    full_name='eolymp.community.Community.AddMember',
    index=4,
    containing_service=None,
    input_type=_ADDMEMBERINPUT,
    output_type=_ADDMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\"\022/community/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMember',
    full_name='eolymp.community.Community.UpdateMember',
    index=5,
    containing_service=None,
    input_type=_UPDATEMEMBERINPUT,
    output_type=_UPDATEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#\032\036/community/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveMember',
    full_name='eolymp.community.Community.RemoveMember',
    index=6,
    containing_service=None,
    input_type=_REMOVEMEMBERINPUT,
    output_type=_REMOVEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#*\036/community/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeMember',
    full_name='eolymp.community.Community.DescribeMember',
    index=7,
    containing_service=None,
    input_type=_DESCRIBEMEMBERINPUT,
    output_type=_DESCRIBEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002(\022\036/community/members/{member_id}b\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='eolymp.community.Community.ListMembers',
    index=8,
    containing_service=None,
    input_type=_LISTMEMBERSINPUT,
    output_type=_LISTMEMBERSOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\022\022/community/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddAttribute',
    full_name='eolymp.community.Community.AddAttribute',
    index=9,
    containing_service=None,
    input_type=_ADDATTRIBUTEINPUT,
    output_type=_ADDATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032\"\025/community/attributesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAttribute',
    full_name='eolymp.community.Community.UpdateAttribute',
    index=10,
    containing_service=None,
    input_type=_UPDATEATTRIBUTEINPUT,
    output_type=_UPDATEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\032%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAttribute',
    full_name='eolymp.community.Community.RemoveAttribute',
    index=11,
    containing_service=None,
    input_type=_REMOVEATTRIBUTEINPUT,
    output_type=_REMOVEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002**%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeAttribute',
    full_name='eolymp.community.Community.DescribeAttribute',
    index=12,
    containing_service=None,
    input_type=_DESCRIBEATTRIBUTEINPUT,
    output_type=_DESCRIBEATTRIBUTEOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\022%/community/attributes/{attribute_key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAttributes',
    full_name='eolymp.community.Community.ListAttributes',
    index=13,
    containing_service=None,
    input_type=_LISTATTRIBUTESINPUT,
    output_type=_LISTATTRIBUTESOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032\022\025/community/attributesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITY)

DESCRIPTOR.services_by_name['Community'] = _COMMUNITY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/inline.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/typewriter/inline.proto',
  package='eolymp.typewriter',
  syntax='proto3',
  serialized_options=b'Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/typewriter/inline.proto\x12\x11\x65olymp.typewriter\"\xdc\x04\n\x06Inline\x12.\n\x04text\x18\x01 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.TextH\x00\x12.\n\x04link\x18\x02 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.LinkH\x00\x12.\n\x04math\x18\x03 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.MathH\x00\x12.\n\x04\x63ode\x18\x04 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.CodeH\x00\x12\x36\n\x08variable\x18\x05 \x01(\x0b\x32\".eolymp.typewriter.Inline.VariableH\x00\x1aO\n\x05Style\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x11\n\tunderline\x18\x03 \x01(\x08\x12\x15\n\rstrikethrough\x18\x04 \x01(\x08\x1a\x43\n\x04Text\x12\x0b\n\x03str\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.Style\x1a@\n\x04Link\x12\x0b\n\x03url\x18\x01 \x01(\t\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a\x17\n\x04\x43ode\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1aH\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.StyleB\x06\n\x04nodeB=Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriterb\x06proto3'
)




_INLINE_STYLE = _descriptor.Descriptor(
  name='Style',
  full_name='eolymp.typewriter.Inline.Style',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bold', full_name='eolymp.typewriter.Inline.Style.bold', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='italic', full_name='eolymp.typewriter.Inline.Style.italic', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underline', full_name='eolymp.typewriter.Inline.Style.underline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikethrough', full_name='eolymp.typewriter.Inline.Style.strikethrough', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=391,
)

_INLINE_TEXT = _descriptor.Descriptor(
  name='Text',
  full_name='eolymp.typewriter.Inline.Text',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='str', full_name='eolymp.typewriter.Inline.Text.str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='eolymp.typewriter.Inline.Text.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=460,
)

_INLINE_LINK = _descriptor.Descriptor(
  name='Link',
  full_name='eolymp.typewriter.Inline.Link',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='eolymp.typewriter.Inline.Link.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='children', full_name='eolymp.typewriter.Inline.Link.children', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=526,
)

_INLINE_MATH = _descriptor.Descriptor(
  name='Math',
  full_name='eolymp.typewriter.Inline.Math',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.typewriter.Inline.Math.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=551,
)

_INLINE_CODE = _descriptor.Descriptor(
  name='Code',
  full_name='eolymp.typewriter.Inline.Code',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.typewriter.Inline.Code.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=576,
)

_INLINE_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='eolymp.typewriter.Inline.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.typewriter.Inline.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='eolymp.typewriter.Inline.Variable.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=650,
)

_INLINE = _descriptor.Descriptor(
  name='Inline',
  full_name='eolymp.typewriter.Inline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='eolymp.typewriter.Inline.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='eolymp.typewriter.Inline.link', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='math', full_name='eolymp.typewriter.Inline.math', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='eolymp.typewriter.Inline.code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='eolymp.typewriter.Inline.variable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INLINE_STYLE, _INLINE_TEXT, _INLINE_LINK, _INLINE_MATH, _INLINE_CODE, _INLINE_VARIABLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='eolymp.typewriter.Inline.node',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=54,
  serialized_end=658,
)

_INLINE_STYLE.containing_type = _INLINE
_INLINE_TEXT.fields_by_name['style'].message_type = _INLINE_STYLE
_INLINE_TEXT.containing_type = _INLINE
_INLINE_LINK.fields_by_name['children'].message_type = _INLINE
_INLINE_LINK.containing_type = _INLINE
_INLINE_MATH.containing_type = _INLINE
_INLINE_CODE.containing_type = _INLINE
_INLINE_VARIABLE.fields_by_name['style'].message_type = _INLINE_STYLE
_INLINE_VARIABLE.containing_type = _INLINE
_INLINE.fields_by_name['text'].message_type = _INLINE_TEXT
_INLINE.fields_by_name['link'].message_type = _INLINE_LINK
_INLINE.fields_by_name['math'].message_type = _INLINE_MATH
_INLINE.fields_by_name['code'].message_type = _INLINE_CODE
_INLINE.fields_by_name['variable'].message_type = _INLINE_VARIABLE
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['text'])
_INLINE.fields_by_name['text'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['link'])
_INLINE.fields_by_name['link'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['math'])
_INLINE.fields_by_name['math'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['code'])
_INLINE.fields_by_name['code'].containing_oneof = _INLINE.oneofs_by_name['node']
_INLINE.oneofs_by_name['node'].fields.append(
  _INLINE.fields_by_name['variable'])
_INLINE.fields_by_name['variable'].containing_oneof = _INLINE.oneofs_by_name['node']
DESCRIPTOR.message_types_by_name['Inline'] = _INLINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Inline = _reflection.GeneratedProtocolMessageType('Inline', (_message.Message,), {

  'Style' : _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_STYLE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Style)
    })
  ,

  'Text' : _reflection.GeneratedProtocolMessageType('Text', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_TEXT,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Text)
    })
  ,

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_LINK,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Link)
    })
  ,

  'Math' : _reflection.GeneratedProtocolMessageType('Math', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_MATH,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Math)
    })
  ,

  'Code' : _reflection.GeneratedProtocolMessageType('Code', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_CODE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Code)
    })
  ,

  'Variable' : _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
    'DESCRIPTOR' : _INLINE_VARIABLE,
    '__module__' : 'eolymp.typewriter.inline_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline.Variable)
    })
  ,
  'DESCRIPTOR' : _INLINE,
  '__module__' : 'eolymp.typewriter.inline_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.Inline)
  })
_sym_db.RegisterMessage(Inline)
_sym_db.RegisterMessage(Inline.Style)
_sym_db.RegisterMessage(Inline.Text)
_sym_db.RegisterMessage(Inline.Link)
_sym_db.RegisterMessage(Inline.Math)
_sym_db.RegisterMessage(Inline.Code)
_sym_db.RegisterMessage(Inline.Variable)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/helpdesk.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/helpdesk/helpdesk.proto',
  package='eolymp.helpdesk',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdesk',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/helpdesk/helpdesk.proto\x12\x0f\x65olymp.helpdesk\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1d\x65olymp/annotations/http.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1e\x65olymp/helpdesk/document.proto\",\n\x15\x44\x65scribeDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeDocumentOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\xa0\x02\n\x12ListDocumentsInput\x12\x14\n\x0csearch_query\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.helpdesk.ListDocumentsInput.Filter\x1a\x98\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04path\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06locale\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"N\n\x13ListDocumentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\"B\n\x13\x43reateDocumentInput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"+\n\x14\x43reateDocumentOutput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"W\n\x13UpdateDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\x12+\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\x16\n\x14UpdateDocumentOutput\"*\n\x13\x44\x65leteDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteDocumentOutput\"<\n\x11\x44\x65scribePathInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"A\n\x12\x44\x65scribePathOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\xfe\x01\n\x0eListPathsInput\x12\x19\n\x11preferred_locales\x18\x01 \x03(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.helpdesk.ListPathsInput.Filter\x1az\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12\x30\n\x04path\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x05label\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x0fListPathsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\";\n\x10ListParentsInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"L\n\x11ListParentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document2\x8a\x0b\n\x08Helpdesk\x12\xc5\x01\n\x10\x44\x65scribeDocument\x12&.eolymp.helpdesk.DescribeDocumentInput\x1a\'.eolymp.helpdesk.DescribeDocumentOutput\"`\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02,\x12 /helpdesk/document/{document_id}:\x08\x64ocument\x12\xa2\x01\n\rListDocuments\x12#.eolymp.helpdesk.ListDocumentsInput\x1a$.eolymp.helpdesk.ListDocumentsOutput\"F\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x13\x12\x11/atlas/documents/\x12\xaa\x01\n\x0e\x43reateDocument\x12$.eolymp.helpdesk.CreateDocumentInput\x1a%.eolymp.helpdesk.CreateDocumentOutput\"K\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\"\x12/helpdesk/document:\x01*\x12\xb8\x01\n\x0eUpdateDocument\x12$.eolymp.helpdesk.UpdateDocumentInput\x1a%.eolymp.helpdesk.UpdateDocumentOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02%\x1a /helpdesk/document/{document_id}:\x01*\x12\xb1\x01\n\x0e\x44\x65leteDocument\x12$.eolymp.helpdesk.DeleteDocumentInput\x1a%.eolymp.helpdesk.DeleteDocumentOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1e*\x19/helpdesk/document/{path}:\x01*\x12\xaf\x01\n\x0c\x44\x65scribePath\x12\".eolymp.helpdesk.DescribePathInput\x1a#.eolymp.helpdesk.DescribePathOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\"\x12\x16/helpdesk/paths/{path}:\x08\x64ocument\x12\x95\x01\n\tListPaths\x12\x1f.eolymp.helpdesk.ListPathsInput\x1a .eolymp.helpdesk.ListPathsOutput\"E\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x11\x12\x0f/helpdesk/paths\x12\xaa\x01\n\x0bListParents\x12!.eolymp.helpdesk.ListParentsInput\x1a\".eolymp.helpdesk.ListParentsOutput\"T\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02 \x12\x1e/helpdesk/paths/{path}/parentsB9Z7github.com/eolymp/contracts/go/eolymp/helpdesk;helpdeskb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_helpdesk_dot_document__pb2.DESCRIPTOR,])




_DESCRIBEDOCUMENTINPUT = _descriptor.Descriptor(
  name='DescribeDocumentInput',
  full_name='eolymp.helpdesk.DescribeDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.DescribeDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=261,
)


_DESCRIBEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='DescribeDocumentOutput',
  full_name='eolymp.helpdesk.DescribeDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DescribeDocumentOutput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=332,
)


_LISTDOCUMENTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.helpdesk.ListDocumentsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.helpdesk.ListDocumentsInput.Filter.locale', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=623,
)

_LISTDOCUMENTSINPUT = _descriptor.Descriptor(
  name='ListDocumentsInput',
  full_name='eolymp.helpdesk.ListDocumentsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_query', full_name='eolymp.helpdesk.ListDocumentsInput.search_query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.helpdesk.ListDocumentsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.helpdesk.ListDocumentsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.helpdesk.ListDocumentsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDOCUMENTSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=623,
)


_LISTDOCUMENTSOUTPUT = _descriptor.Descriptor(
  name='ListDocumentsOutput',
  full_name='eolymp.helpdesk.ListDocumentsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListDocumentsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListDocumentsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=703,
)


_CREATEDOCUMENTINPUT = _descriptor.Descriptor(
  name='CreateDocumentInput',
  full_name='eolymp.helpdesk.CreateDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.CreateDocumentInput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=771,
)


_CREATEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='CreateDocumentOutput',
  full_name='eolymp.helpdesk.CreateDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.CreateDocumentOutput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=816,
)


_UPDATEDOCUMENTINPUT = _descriptor.Descriptor(
  name='UpdateDocumentInput',
  full_name='eolymp.helpdesk.UpdateDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.UpdateDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.UpdateDocumentInput.document', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=905,
)


_UPDATEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='UpdateDocumentOutput',
  full_name='eolymp.helpdesk.UpdateDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=929,
)


_DELETEDOCUMENTINPUT = _descriptor.Descriptor(
  name='DeleteDocumentInput',
  full_name='eolymp.helpdesk.DeleteDocumentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_id', full_name='eolymp.helpdesk.DeleteDocumentInput.document_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=973,
)


_DELETEDOCUMENTOUTPUT = _descriptor.Descriptor(
  name='DeleteDocumentOutput',
  full_name='eolymp.helpdesk.DeleteDocumentOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=997,
)


_DESCRIBEPATHINPUT = _descriptor.Descriptor(
  name='DescribePathInput',
  full_name='eolymp.helpdesk.DescribePathInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.DescribePathInput.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.DescribePathInput.preferred_locales', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1059,
)


_DESCRIBEPATHOUTPUT = _descriptor.Descriptor(
  name='DescribePathOutput',
  full_name='eolymp.helpdesk.DescribePathOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='eolymp.helpdesk.DescribePathOutput.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1126,
)


_LISTPATHSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.helpdesk.ListPathsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='eolymp.helpdesk.ListPathsInput.Filter.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListPathsInput.Filter.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.helpdesk.ListPathsInput.Filter.label', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1383,
)

_LISTPATHSINPUT = _descriptor.Descriptor(
  name='ListPathsInput',
  full_name='eolymp.helpdesk.ListPathsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.ListPathsInput.preferred_locales', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.helpdesk.ListPathsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.helpdesk.ListPathsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.helpdesk.ListPathsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPATHSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1383,
)


_LISTPATHSOUTPUT = _descriptor.Descriptor(
  name='ListPathsOutput',
  full_name='eolymp.helpdesk.ListPathsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListPathsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListPathsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1459,
)


_LISTPARENTSINPUT = _descriptor.Descriptor(
  name='ListParentsInput',
  full_name='eolymp.helpdesk.ListParentsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='eolymp.helpdesk.ListParentsInput.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.helpdesk.ListParentsInput.preferred_locales', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1461,
  serialized_end=1520,
)


_LISTPARENTSOUTPUT = _descriptor.Descriptor(
  name='ListParentsOutput',
  full_name='eolymp.helpdesk.ListParentsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.helpdesk.ListParentsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.helpdesk.ListParentsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1598,
)

_DESCRIBEDOCUMENTOUTPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['path'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTDOCUMENTSINPUT_FILTER.fields_by_name['locale'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTDOCUMENTSINPUT_FILTER.containing_type = _LISTDOCUMENTSINPUT
_LISTDOCUMENTSINPUT.fields_by_name['filters'].message_type = _LISTDOCUMENTSINPUT_FILTER
_LISTDOCUMENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_CREATEDOCUMENTINPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_UPDATEDOCUMENTINPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_DESCRIBEPATHOUTPUT.fields_by_name['document'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTPATHSINPUT_FILTER.fields_by_name['path'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTPATHSINPUT_FILTER.fields_by_name['label'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTPATHSINPUT_FILTER.containing_type = _LISTPATHSINPUT
_LISTPATHSINPUT.fields_by_name['filters'].message_type = _LISTPATHSINPUT_FILTER
_LISTPATHSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
_LISTPARENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_helpdesk_dot_document__pb2._DOCUMENT
DESCRIPTOR.message_types_by_name['DescribeDocumentInput'] = _DESCRIBEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['DescribeDocumentOutput'] = _DESCRIBEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['ListDocumentsInput'] = _LISTDOCUMENTSINPUT
DESCRIPTOR.message_types_by_name['ListDocumentsOutput'] = _LISTDOCUMENTSOUTPUT
DESCRIPTOR.message_types_by_name['CreateDocumentInput'] = _CREATEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['CreateDocumentOutput'] = _CREATEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateDocumentInput'] = _UPDATEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['UpdateDocumentOutput'] = _UPDATEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteDocumentInput'] = _DELETEDOCUMENTINPUT
DESCRIPTOR.message_types_by_name['DeleteDocumentOutput'] = _DELETEDOCUMENTOUTPUT
DESCRIPTOR.message_types_by_name['DescribePathInput'] = _DESCRIBEPATHINPUT
DESCRIPTOR.message_types_by_name['DescribePathOutput'] = _DESCRIBEPATHOUTPUT
DESCRIPTOR.message_types_by_name['ListPathsInput'] = _LISTPATHSINPUT
DESCRIPTOR.message_types_by_name['ListPathsOutput'] = _LISTPATHSOUTPUT
DESCRIPTOR.message_types_by_name['ListParentsInput'] = _LISTPARENTSINPUT
DESCRIPTOR.message_types_by_name['ListParentsOutput'] = _LISTPARENTSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DescribeDocumentInput = _reflection.GeneratedProtocolMessageType('DescribeDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribeDocumentInput)
  })
_sym_db.RegisterMessage(DescribeDocumentInput)

DescribeDocumentOutput = _reflection.GeneratedProtocolMessageType('DescribeDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribeDocumentOutput)
  })
_sym_db.RegisterMessage(DescribeDocumentOutput)

ListDocumentsInput = _reflection.GeneratedProtocolMessageType('ListDocumentsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTDOCUMENTSINPUT_FILTER,
    '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTDOCUMENTSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsInput)
  })
_sym_db.RegisterMessage(ListDocumentsInput)
_sym_db.RegisterMessage(ListDocumentsInput.Filter)

ListDocumentsOutput = _reflection.GeneratedProtocolMessageType('ListDocumentsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOCUMENTSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListDocumentsOutput)
  })
_sym_db.RegisterMessage(ListDocumentsOutput)

CreateDocumentInput = _reflection.GeneratedProtocolMessageType('CreateDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.CreateDocumentInput)
  })
_sym_db.RegisterMessage(CreateDocumentInput)

CreateDocumentOutput = _reflection.GeneratedProtocolMessageType('CreateDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.CreateDocumentOutput)
  })
_sym_db.RegisterMessage(CreateDocumentOutput)

UpdateDocumentInput = _reflection.GeneratedProtocolMessageType('UpdateDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.UpdateDocumentInput)
  })
_sym_db.RegisterMessage(UpdateDocumentInput)

UpdateDocumentOutput = _reflection.GeneratedProtocolMessageType('UpdateDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.UpdateDocumentOutput)
  })
_sym_db.RegisterMessage(UpdateDocumentOutput)

DeleteDocumentInput = _reflection.GeneratedProtocolMessageType('DeleteDocumentInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOCUMENTINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DeleteDocumentInput)
  })
_sym_db.RegisterMessage(DeleteDocumentInput)

DeleteDocumentOutput = _reflection.GeneratedProtocolMessageType('DeleteDocumentOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOCUMENTOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DeleteDocumentOutput)
  })
_sym_db.RegisterMessage(DeleteDocumentOutput)

DescribePathInput = _reflection.GeneratedProtocolMessageType('DescribePathInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribePathInput)
  })
_sym_db.RegisterMessage(DescribePathInput)

DescribePathOutput = _reflection.GeneratedProtocolMessageType('DescribePathOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.DescribePathOutput)
  })
_sym_db.RegisterMessage(DescribePathOutput)

ListPathsInput = _reflection.GeneratedProtocolMessageType('ListPathsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTPATHSINPUT_FILTER,
    '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTPATHSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsInput)
  })
_sym_db.RegisterMessage(ListPathsInput)
_sym_db.RegisterMessage(ListPathsInput.Filter)

ListPathsOutput = _reflection.GeneratedProtocolMessageType('ListPathsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPATHSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListPathsOutput)
  })
_sym_db.RegisterMessage(ListPathsOutput)

ListParentsInput = _reflection.GeneratedProtocolMessageType('ListParentsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARENTSINPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListParentsInput)
  })
_sym_db.RegisterMessage(ListParentsInput)

ListParentsOutput = _reflection.GeneratedProtocolMessageType('ListParentsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARENTSOUTPUT,
  '__module__' : 'eolymp.helpdesk.helpdesk_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.helpdesk.ListParentsOutput)
  })
_sym_db.RegisterMessage(ListParentsOutput)


DESCRIPTOR._options = None

_HELPDESK = _descriptor.ServiceDescriptor(
  name='Helpdesk',
  full_name='eolymp.helpdesk.Helpdesk',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1601,
  serialized_end=3019,
  methods=[
  _descriptor.MethodDescriptor(
    name='DescribeDocument',
    full_name='eolymp.helpdesk.Helpdesk.DescribeDocument',
    index=0,
    containing_service=None,
    input_type=_DESCRIBEDOCUMENTINPUT,
    output_type=_DESCRIBEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002,\022 /helpdesk/document/{document_id}:\010document',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDocuments',
    full_name='eolymp.helpdesk.Helpdesk.ListDocuments',
    index=1,
    containing_service=None,
    input_type=_LISTDOCUMENTSINPUT,
    output_type=_LISTDOCUMENTSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\023\022\021/atlas/documents/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDocument',
    full_name='eolymp.helpdesk.Helpdesk.CreateDocument',
    index=2,
    containing_service=None,
    input_type=_CREATEDOCUMENTINPUT,
    output_type=_CREATEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\"\022/helpdesk/document:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDocument',
    full_name='eolymp.helpdesk.Helpdesk.UpdateDocument',
    index=3,
    containing_service=None,
    input_type=_UPDATEDOCUMENTINPUT,
    output_type=_UPDATEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002%\032 /helpdesk/document/{document_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDocument',
    full_name='eolymp.helpdesk.Helpdesk.DeleteDocument',
    index=4,
    containing_service=None,
    input_type=_DELETEDOCUMENTINPUT,
    output_type=_DELETEDOCUMENTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\036*\031/helpdesk/document/{path}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribePath',
    full_name='eolymp.helpdesk.Helpdesk.DescribePath',
    index=5,
    containing_service=None,
    input_type=_DESCRIBEPATHINPUT,
    output_type=_DESCRIBEPATHOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\"\022\026/helpdesk/paths/{path}:\010document',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPaths',
    full_name='eolymp.helpdesk.Helpdesk.ListPaths',
    index=6,
    containing_service=None,
    input_type=_LISTPATHSINPUT,
    output_type=_LISTPATHSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\021\022\017/helpdesk/paths',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListParents',
    full_name='eolymp.helpdesk.Helpdesk.ListParents',
    index=7,
    containing_service=None,
    input_type=_LISTPARENTSINPUT,
    output_type=_LISTPARENTSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002 \022\036/helpdesk/paths/{path}/parents',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HELPDESK)

DESCRIPTOR.services_by_name['Helpdesk'] = _HELPDESK

# @@protoc_insertion_point(module_scope)
